package net.minecraft.src.ic2.api;

/**
 * @file
 * @author Player
 * @version 1.0
 *
 * @section DESCRIPTION
 *
 * The explosion code by default ignores blocks which absorb more than 1k explosion power to
 * prevent abusing personal safes, trade-o-mats and other similar blocks to serve as a cheap and
 * invulnerable reactor chamber.
 * Those blocks will be treated just like air blocks (don't shield the explosion) and won't get
 * destroyed.
 * The ExplosionWhitelist class can be used to prevent that behavior, blocks listed in the
 * whitelist will be treated like any other block with an absorption < 1000 and therefor shield
 * explosions as expected.
 * Register your undestructible shielding blocks here, e.g. something like bedrock or force fields.
 */

import java.util.*;

import net.minecraft.src.Block;

public final class ExplosionWhitelist {
	/**
	 * Add a specific block to the whitelist
	 */
	public static void addWhitelistedBlock(Block block) {
		whitelist.add(block);
	}
	
	/**
	 * Remove a specific block from the whitelist
	 */
	public static void removeWhitelistedBlock(Block block) {
		whitelist.remove(block);
	}
	
	/**
	 * Check if a specific block is whitelisted
	 */
	public static boolean isBlockWhitelisted(Block block) {
		return whitelist.contains(block);
	}

	private static Set<Block> whitelist = new HashSet<Block>();
}

