package net.minecraft.src.ic2.api;

/**
 * @file
 * @author Player, Alblaka
 * @version 1.0
 *
 * @section DESCRIPTION
 *
 * The IElectricItem interface has to be implemented by items which store energy.
 *
 * Chargeable Items should have a max. damage of 13.
 */

import net.minecraft.src.ItemStack;

public interface IElectricItem {
	/**
	 * Determine if the item can be used in a machine to supply energy
	 */
	boolean canProvideEnergy();
	
	/**
	 * Get the item id to use for a charge energy > 0
	 */
	int getChargedItemId();
	
	/**
	 * Get the item id to use for a charge energy == 0
	 */
	int getEmptyItemId();
	
	/**
	 * Get the item's maximum charge energy (in EU)
	 */
	int getMaxCharge();
	
	/**
	 * Get the item's tier, lower tiers can't send energy to higher ones
	 */
	int getTier();
	
	/**
	 * Get the item's transfer power limit
	 */
	int getTransferLimit();
}

